.. Use python as the default language for syntax highlighting in this file
.. highlight:: python

.. default-domain:: py

zoidberg package
================

Module contents
---------------

.. automodule:: zoidberg
    :members:
    :undoc-members:

Submodules
----------

zoidberg.boundary module
------------------------

.. automodule:: zoidberg.boundary
    :members:
    :undoc-members:

zoidberg.field module
---------------------

.. automodule:: zoidberg.field
    :members:
    :undoc-members:

zoidberg.fieldtracer module
---------------------------

.. automodule:: zoidberg.fieldtracer
    :members:
    :undoc-members:

zoidberg.grid module
--------------------

.. automodule:: zoidberg.grid
    :members:
    :undoc-members:

zoidberg.plot module
--------------------

.. automodule:: zoidberg.plot
    :members:
    :undoc-members:

zoidberg.poloidal\_grid module
------------------------------

.. automodule:: zoidberg.poloidal_grid
    :members:
    :undoc-members:

zoidberg.progress module
------------------------

.. automodule:: zoidberg.progress
    :members:
    :undoc-members:

zoidberg.rzline module
----------------------

.. automodule:: zoidberg.rzline
    :members:
    :undoc-members:

zoidberg.zoidberg module
------------------------

.. automodule:: zoidberg.zoidberg
    :members:
    :undoc-members:
